from distutils.core import setup

setup(
    name = 'wood_nester',
    version = '1.1.2',
    py_modules= ['wood_nester'],
    author = 'wood',
    author_email = 'lezvinskyi@gmail.com',
    url = 'https://www.booksaround.net',
    description= 'Simple printer of nested lists'
)